@@ -81,7 +81,7 @@ class Application:
         self.default_theme = self._app_name  # type: str # Default theme is the application name
         self._default_language = "en_US"  # type: str
 
-        self.change_log_url = "https://github.com/Ultimaker/Uranium"  # Where to find a more detailed description of the recent updates.
+        self.change_log_url: str = "https://github.com/Ultimaker/Uranium"  # Where to find a more detailed description of the recent updates.
 
         self._preferences_filename = None  # type: str
         self._preferences = None  # type: Preferences
