@@ -9,7 +9,6 @@ import stat  # For setting file permissions correctly;
 import time
 import types
 import zipfile
-from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional, Tuple, TYPE_CHECKING
 
 from PyQt5.QtCore import QCoreApplication
@@ -176,13 +175,6 @@ class PluginRegistry(QObject):
             # There is no need to crash the application for this, but it is a failure that we want to log.
             Logger.logException("e", "Unable to save the plugin data.")
 
-    def _isPathInLocation(self, location: str, path: str) -> bool:
-        try:
-            is_in_path = os.path.commonpath([location, path]).startswith(location)
-        except ValueError:
-            is_in_path = False
-        return is_in_path
-
     # TODO:
     # - [ ] Improve how metadata is stored. It should not be in the 'plugin' prop
     #       of the dictionary item.
@@ -335,7 +327,7 @@ class PluginRegistry(QObject):
         # Go through all plugin locations and check if the given plugin is located in the installation path.
         is_bundled = False
         for plugin_dir in self._plugin_locations:
-            if not self._isPathInLocation(install_prefix, plugin_dir):
+            if not TrustBasics.isPathInLocation(install_prefix, plugin_dir):
                 # To prevent the situation in a 'trusted' env. that the user-folder has a supposedly 'bundled' plugin:
                 if self._check_if_trusted:
                     result = self._locatePlugin(plugin_id, plugin_dir)
@@ -384,7 +376,7 @@ class PluginRegistry(QObject):
                 Logger.error("Plugin {} was not loaded because it could not be verified.", plugin_id)
                 message_text = i18n_catalog.i18nc("@error:untrusted",
                                                   "Plugin {} was not loaded because it could not be verified.", plugin_id)
-                Message(text = message_text).show()
+                Message(text = message_text, message_type = Message.MessageType.ERROR).show()
                 continue
 
             # Save all metadata to the metadata dictionary:
@@ -482,12 +474,12 @@ class PluginRegistry(QObject):
             message_text = i18n_catalog.i18nc("@error",
                                               "The plugin {} could not be loaded. Re-installing the plugin might solve "
                                               "the issue", plugin_id)
-            unable_to_load_plugin_message = Message(text = message_text)
+            unable_to_load_plugin_message = Message(text = message_text, message_type = Message.MessageType.ERROR)
             unable_to_load_plugin_message.addAction("remove",
-                                   name= i18n_catalog.i18nc("@action:button", "Remove plugin"),
-                                   icon="",
-                                   description="Remove the plugin",
-                                   button_align=Message.ActionButtonAlignment.ALIGN_RIGHT)
+                                   name = i18n_catalog.i18nc("@action:button", "Remove plugin"),
+                                   icon = "",
+                                   description = "Remove the plugin",
+                                   button_align = Message.ActionButtonAlignment.ALIGN_RIGHT)
 
             # Listen for the pyqt signal, since that one does support lambda's
             unable_to_load_plugin_message.pyQtActionTriggered.connect(lambda message, action: (self.uninstallPlugin(plugin_id), message.hide()))
@@ -641,9 +633,10 @@ class PluginRegistry(QObject):
                 try:
                     with open(metadata_file, "r", encoding="utf-8") as file_stream:
                         self._parsePluginInfo(plugin_id, file_stream.read(), meta_data)
-                except:
-                    pass
-                current_version = Version(meta_data["plugin"]["version"])
+                    current_version = Version(meta_data["plugin"]["version"])
+                except InvalidMetaDataError:
+                    current_version = Version("0.0.0")
+                    Logger.log("e", f"The plugin.json in '{plugin_location}' is invalid. Assuming that the version of '{plugin_id}' is {current_version}.")
                 if current_version > highest_version:
                     highest_version = current_version
                     final_location = loc
@@ -651,9 +644,19 @@ class PluginRegistry(QObject):
         # Move data (if any) to central storage
         central_storage_file = os.path.join(final_location, plugin_id, TrustBasics.getCentralStorageFilename())
         if os.path.exists(central_storage_file):
+            plugin_final_path = os.path.join(final_location, plugin_id)
+
+            if self._check_if_trusted and plugin_id not in self._checked_plugin_ids and not self.isBundledPlugin(plugin_id):
+                # Do a quick check if the central-storage file itself hasn't been tampered with (and such).
+                # This is necessary, as we move to central storage first, and only _then_ properly check the manifest.
+                if self._trust_checker and not self._trust_checker.signedFolderPreStorageCheck(plugin_final_path):
+                    self._distrusted_plugin_ids.append(plugin_id)
+                    return None
+
             try:
                 with open(central_storage_file, "r", encoding = "utf-8") as file_stream:
-                    self._handleCentralStorage(file_stream.read(), os.path.join(final_location, plugin_id), is_bundled_plugin = self.isBundledPlugin(plugin_id))
+                    if not self._handleCentralStorage(file_stream.read(), plugin_final_path, is_bundled_plugin = self.isBundledPlugin(plugin_id)):
+                        return None
             except:
                 pass
         try:
@@ -710,25 +713,27 @@ class PluginRegistry(QObject):
 
         return None
 
-    def _handleCentralStorage(self, file_data: str, plugin_path: str, is_bundled_plugin: bool = False) -> None:
+    def _handleCentralStorage(self, file_data: str, plugin_path: str, is_bundled_plugin: bool = False) -> bool:
         """
         Plugins can indicate that they want certain things to be stored in a central location.
         In the case of a signed plugin you *must* do this by means of the central_storage.json file.
         :param file_data: The data as loaded from the file
         :param plugin_path: The location of the plugin on the file system
-        :return:
+        :return: False if there is a security suspicion, True otherwise (even if the method otherwise fails).
         """
         try:
             file_manifest = json.loads(file_data)
         except (json.decoder.JSONDecodeError, UnicodeDecodeError):
-            Logger.logException("e", "Failed to parse central_storage.json")
-            return
+            Logger.logException("e", f"Failed to parse the central storage file for '{plugin_path}'.")
+            return True
 
         for file_to_move in file_manifest:
+            full_path = os.path.join(plugin_path, file_to_move[0])
             try:
-                CentralFileStorage.store(os.path.join(plugin_path, file_to_move[0]), file_to_move[1], Version(file_to_move[2]), move_file = not is_bundled_plugin)
-            except (TypeError, IndexError):
-                Logger.logException("w", "Unable to move file to central storage")
+                CentralFileStorage.store(full_path, file_to_move[1], Version(file_to_move[2]), move_file = not is_bundled_plugin)
+            except (FileExistsError, TypeError, IndexError, OSError):
+                Logger.logException("w", f"Can't move file {file_to_move[0]} to central storage for '{plugin_path}'.")
+        return True
 
     #   Load the plugin data from the stream and in-place update the metadata.
     def _parsePluginInfo(self, plugin_id, file_data, meta_data):
