@@ -140,8 +140,7 @@ class QtApplication(QApplication, Application):
         #  - The language in use, so the splash window can be shown in the correct language.
         #  - The OpenGL 'force' parameters.
         try:
-            preferences_filename = Resources.getPath(Resources.Preferences, self._app_name + ".cfg")
-            self._preferences.readFromFile(preferences_filename)
+            self.readPreferencesFromConfiguration()
         except FileNotFoundError:
             Logger.log("i", "Preferences file not found, ignore and use default language '%s'", self._default_language)
 
@@ -186,6 +185,12 @@ class QtApplication(QApplication, Application):
         Logger.log("i", "Initializing version upgrade manager ...")
         self._version_upgrade_manager = VersionUpgradeManager(self)
 
+    def _displayLoadingPluginSplashMessage(self, plugin_id: Optional[str]) -> None:
+        message = i18nCatalog("uranium").i18nc("@info:progress", "Loading plugins...")
+        if plugin_id:
+            message = i18nCatalog("uranium").i18nc("@info:progress", "Loading plugin {plugin_id}...").format(plugin_id = plugin_id)
+        self.showSplashMessage(message)
+
     def startSplashWindowPhase(self) -> None:
         super().startSplashWindowPhase()
         i18n_catalog = i18nCatalog("uranium")
@@ -205,7 +210,9 @@ class QtApplication(QApplication, Application):
         self.showSplashMessage(i18n_catalog.i18nc("@info:progress", "Loading plugins..."))
         # Remove and install the plugins that have been scheduled
         self._plugin_registry.initializeBeforePluginsAreLoaded()
+        self._plugin_registry.pluginLoadStarted.connect(self._displayLoadingPluginSplashMessage)
         self._loadPlugins()
+        self._plugin_registry.pluginLoadStarted.disconnect(self._displayLoadingPluginSplashMessage)
         self._plugin_registry.checkRequiredPlugins(self.getRequiredPlugins())
         self.pluginsLoaded.emit()
 
@@ -230,8 +237,7 @@ class QtApplication(QApplication, Application):
         self.processEvents()
         # Force the configuration file to be written again since the list of plugins to remove maybe changed
         try:
-            self._preferences_filename = Resources.getPath(Resources.Preferences, self._app_name + ".cfg")
-            self._preferences.readFromFile(self._preferences_filename)
+            self.readPreferencesFromConfiguration()
         except FileNotFoundError:
             Logger.log("i", "The preferences file '%s' cannot be found, will use default values",
                        self._preferences_filename)
@@ -275,6 +281,10 @@ class QtApplication(QApplication, Application):
                 except FileNotFoundError:
                     Logger.log("w", "Could not find the icon %s", self._tray_icon_name)
 
+    def readPreferencesFromConfiguration(self) -> None:
+        self._preferences_filename = Resources.getPath(Resources.Preferences, self._app_name + ".cfg")
+        self._preferences.readFromFile(self._preferences_filename)
+
     def initializeEngine(self) -> None:
         # TODO: Document native/qml import trickery
         self._qml_engine = QQmlApplicationEngine(self)
