@@ -45,7 +45,7 @@ class SelectionPass(RenderPass):
         self._renderer = Application.getInstance().getRenderer()
 
         self._selection_map = {}
-        self._toolhandle_selection_map = {
+        self._default_toolhandle_selection_map = {
             self._dropAlpha(ToolHandle.DisabledSelectionColor): ToolHandle.NoAxis,
             self._dropAlpha(ToolHandle.XAxisSelectionColor): ToolHandle.XAxis,
             self._dropAlpha(ToolHandle.YAxisSelectionColor): ToolHandle.YAxis,
@@ -57,12 +57,29 @@ class SelectionPass(RenderPass):
             ToolHandle.ZAxisSelectionColor: ToolHandle.ZAxis,
             ToolHandle.AllAxisSelectionColor: ToolHandle.AllAxis
         }
+        self._toolhandle_selection_map = {}
+        Application.getInstance().getController().activeToolChanged.connect(self._onActiveToolChanged)
+        self._onActiveToolChanged()
 
         self._mode = SelectionPass.SelectionMode.OBJECTS
         Selection.selectedFaceChanged.connect(self._onSelectedFaceChanged)
 
         self._output = None
 
+    def _onActiveToolChanged(self):
+        self._toolhandle_selection_map = self._default_toolhandle_selection_map.copy()
+
+        active_tool = Application.getInstance().getController().getActiveTool()
+        if not active_tool:
+            return
+
+        tool_handle = active_tool.getHandle()
+        if not tool_handle:
+            return
+        for name, color in tool_handle.getExtraWidgetsColorMap().items():
+            self._toolhandle_selection_map[color] = name
+            self._toolhandle_selection_map[self._dropAlpha(color)] = name
+
     def _onSelectedFaceChanged(self):
         self._mode = SelectionPass.SelectionMode.FACES if Selection.getFaceSelectMode() else SelectionPass.SelectionMode.OBJECTS
 
@@ -81,12 +98,12 @@ class SelectionPass(RenderPass):
         selectable_objects = False
         for node in DepthFirstIterator(self._scene.getRoot()):
             if isinstance(node, ToolHandle):
-                tool_handle.addItem(node.getWorldTransformation(), mesh = node.getSelectionMesh())
+                tool_handle.addItem(node.getWorldTransformation(copy = False), mesh = node.getSelectionMesh())
                 continue
 
             if node.isSelectable() and node.getMeshData():
                 selectable_objects = True
-                batch.addItem(transformation = node.getWorldTransformation(), mesh = node.getMeshData(), uniforms = { "selection_color": self._getNodeColor(node)})
+                batch.addItem(transformation = node.getWorldTransformation(copy = False), mesh = node.getMeshData(), uniforms = { "selection_color": self._getNodeColor(node)}, normal_transformation=node.getCachedNormalMatrix())
 
         self.bind()
         if selectable_objects:
@@ -112,7 +129,7 @@ class SelectionPass(RenderPass):
 
             if node.isSelectable() and node.getMeshData():
                 selectable_objects = True
-                batch.addItem(transformation = node.getWorldTransformation(), mesh = node.getMeshData())
+                batch.addItem(transformation = node.getWorldTransformation(copy = False), mesh = node.getMeshData(), normal_transformation=node.getCachedNormalMatrix())
 
         self.bind()
         if selectable_objects:
@@ -126,8 +143,8 @@ class SelectionPass(RenderPass):
 
         window_size = self._renderer.getWindowSize()
 
-        px = (0.5 + x / 2.0) * window_size[0]
-        py = (0.5 + y / 2.0) * window_size[1]
+        px = round((0.5 + x / 2.0) * window_size[0])
+        py = round((0.5 + y / 2.0) * window_size[1])
 
         if px < 0 or px > (output.width() - 1) or py < 0 or py > (output.height() - 1):
             return None
